@@ -1,137 +1,137 @@
-##' urlTemplate function
-##'
-##' A function to return a url for a leaflet template for use as map backgrounds with the spplot1 function.
-##'
-##' Possible templates are: OpenStreetMap_Mapnik, OpenStreetMap_BlackAndWhite, OpenStreetMap_DE, 
-##' OpenStreetMap_France, OpenStreetMap_HOT, OpenTopoMap, Thunderforest_OpenCycleMap, Thunderforest_Transport, 
-##' Thunderforest_Landscape, Thunderforest_Outdoors, OpenMapSurfer_Roads, OpenMapSurfer_Grayscale, Hydda_Full, 
-##' Hydda_Base, MapQuestOpen_OSM, Stamen_Toner, Stamen_TonerBackground, Stamen_TonerLite, Stamen_Watercolor, 
-##' Stamen_Terrain, Stamen_TerrainBackground, Stamen_TopOSMRelief, Esri_WorldStreetMap, Esri_WorldTopoMap, 
-##' Esri_WorldImagery, Esri_WorldTerrain, Esri_WorldShadedRelief, Esri_WorldPhysical, Esri_OceanBasemap, 
-##' Esri_NatGeoWorldMap, Esri_WorldGrayCanvas, Acetate_all, Acetate_terrain, HERE_satelliteDay, 
-##' HERE_hybridDayMobile, HERE_hybridDay
-##'
-##' See \url{http://leaflet-extras.github.io/leaflet-providers/preview/} for other leaflet templates
-##'
-##' @param name name of the template to use, the default is 'Stamen_Toner'
-##' @return url for the leaflet template
-##' @export
+## urlTemplate function
+##
+## A function to return a url for a leaflet template for use as map backgrounds with the spplot1 function.
+##
+## Possible templates are: OpenStreetMap_Mapnik, OpenStreetMap_BlackAndWhite, OpenStreetMap_DE, 
+## OpenStreetMap_France, OpenStreetMap_HOT, OpenTopoMap, Thunderforest_OpenCycleMap, Thunderforest_Transport, 
+## Thunderforest_Landscape, Thunderforest_Outdoors, OpenMapSurfer_Roads, OpenMapSurfer_Grayscale, Hydda_Full, 
+## Hydda_Base, MapQuestOpen_OSM, Stamen_Toner, Stamen_TonerBackground, Stamen_TonerLite, Stamen_Watercolor, 
+## Stamen_Terrain, Stamen_TerrainBackground, Stamen_TopOSMRelief, Esri_WorldStreetMap, Esri_WorldTopoMap, 
+## Esri_WorldImagery, Esri_WorldTerrain, Esri_WorldShadedRelief, Esri_WorldPhysical, Esri_OceanBasemap, 
+## Esri_NatGeoWorldMap, Esri_WorldGrayCanvas, Acetate_all, Acetate_terrain, HERE_satelliteDay, 
+## HERE_hybridDayMobile, HERE_hybridDay
+##
+## See \url{http://leaflet-extras.github.io/leaflet-providers/preview/} for other leaflet templates
+##
+## @param name name of the template to use, the default is 'Stamen_Toner'
+## @return url for the leaflet template
+## @export
 
-urlTemplate <- function(name="Stamen_Toner"){
-
-    if(name=="OpenStreetMap_Mapnik"){
-        return("http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenStreetMap_BlackAndWhite"){
-        return("http://{s}.tiles.wmflabs.org/bw-mapnik/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenStreetMap_DE"){
-        return("http://{s}.tile.openstreetmap.de/tiles/osmde/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenStreetMap_France"){
-        return("http://{s}.tile.openstreetmap.fr/osmfr/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenStreetMap_HOT"){
-        return("http://{s}.tile.openstreetmap.fr/hot/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenTopoMap"){
-        return("http://{s}.tile.opentopomap.org/{z}/{x}/{y}.png")
-    }
-    else if(name=="Thunderforest_OpenCycleMap"){
-        return("http://{s}.tile.thunderforest.com/cycle/{z}/{x}/{y}.png")
-    }
-    else if(name=="Thunderforest_Transport"){
-        return("http://{s}.tile.thunderforest.com/transport/{z}/{x}/{y}.png")
-    }
-    else if(name=="Thunderforest_Landscape"){
-        return("http://{s}.tile.thunderforest.com/landscape/{z}/{x}/{y}.png")
-    }
-    else if(name=="Thunderforest_Outdoors"){
-        return("http://{s}.tile.thunderforest.com/outdoors/{z}/{x}/{y}.png")
-    }
-    else if(name=="OpenMapSurfer_Roads"){
-        return("http://openmapsurfer.uni-hd.de/tiles/roads/x={x}&y={y}&z={z}")
-    }
-    else if(name=="OpenMapSurfer_Grayscale"){
-        return("http://openmapsurfer.uni-hd.de/tiles/roadsg/x={x}&y={y}&z={z}")
-    }
-    else if(name=="Hydda_Full"){
-        return("http://{s}.tile.openstreetmap.se/hydda/full/{z}/{x}/{y}.png")
-    }
-    else if(name=="Hydda_Base"){
-        return("http://{s}.tile.openstreetmap.se/hydda/base/{z}/{x}/{y}.png")
-    }
-    else if(name=="MapQuestOpen_OSM"){
-        return("http://otile{s}.mqcdn.com/tiles/1.0.0/{type}/{z}/{x}/{y}.{ext}")
-    }
-    else if(name=="Stamen_Toner"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_TonerBackground"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner-background/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_TonerLite"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner-lite/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_Watercolor"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_Terrain"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_TerrainBackground"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/terrain-background/{z}/{x}/{y}.png")
-    }
-    else if(name=="Stamen_TopOSMRelief"){
-        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toposm-color-relief/{z}/{x}/{y}.png")
-    }
-    else if(name=="Esri_WorldStreetMap"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldTopoMap"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldImagery"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldTerrain"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Terrain_Base/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldShadedRelief"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Shaded_Relief/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldPhysical"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Physical_Map/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_OceanBasemap"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/Ocean_Basemap/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_NatGeoWorldMap"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/NatGeo_World_Map/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Esri_WorldGrayCanvas"){
-        return("http://server.arcgisonline.com/ArcGIS/rest/services/Canvas/World_Light_Gray_Base/MapServer/tile/{z}/{y}/{x}")
-    }
-    else if(name=="Acetate_all"){
-        return("http://a{s}.acetate.geoiq.com/tiles/acetate-hillshading/{z}/{x}/{y}.png")
-    }
-    else if(name=="Acetate_terrain"){
-        return("http://a{s}.acetate.geoiq.com/tiles/terrain/{z}/{x}/{y}.png")
-    }
-    else if(name=="HERE_satelliteDay"){
-        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/satellite.day/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
-    }
-    else if(name=="HERE_hybridDayMobile"){
-        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/hybrid.day.mobile/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
-    }
-    else if(name=="HERE_hybridDay"){
-        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/hybrid.day/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
-    }
-    else{
-        stop("Map layer not currently supported. Note that you can ")
-    } 
-
-}
+#urlTemplate <- function(name="Stamen_Toner"){
+#
+#    if(name=="OpenStreetMap_Mapnik"){
+#        return("http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenStreetMap_BlackAndWhite"){
+#        return("http://{s}.tiles.wmflabs.org/bw-mapnik/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenStreetMap_DE"){
+#        return("http://{s}.tile.openstreetmap.de/tiles/osmde/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenStreetMap_France"){
+#        return("http://{s}.tile.openstreetmap.fr/osmfr/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenStreetMap_HOT"){
+#        return("http://{s}.tile.openstreetmap.fr/hot/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenTopoMap"){
+#        return("http://{s}.tile.opentopomap.org/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Thunderforest_OpenCycleMap"){
+#        return("http://{s}.tile.thunderforest.com/cycle/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Thunderforest_Transport"){
+#        return("http://{s}.tile.thunderforest.com/transport/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Thunderforest_Landscape"){
+#        return("http://{s}.tile.thunderforest.com/landscape/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Thunderforest_Outdoors"){
+#        return("http://{s}.tile.thunderforest.com/outdoors/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="OpenMapSurfer_Roads"){
+#        return("http://openmapsurfer.uni-hd.de/tiles/roads/x={x}&y={y}&z={z}")
+#    }
+#    else if(name=="OpenMapSurfer_Grayscale"){
+#        return("http://openmapsurfer.uni-hd.de/tiles/roadsg/x={x}&y={y}&z={z}")
+#    }
+#    else if(name=="Hydda_Full"){
+#        return("http://{s}.tile.openstreetmap.se/hydda/full/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Hydda_Base"){
+#        return("http://{s}.tile.openstreetmap.se/hydda/base/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="MapQuestOpen_OSM"){
+#        return("http://otile{s}.mqcdn.com/tiles/1.0.0/{type}/{z}/{x}/{y}.{ext}")
+#    }
+#    else if(name=="Stamen_Toner"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_TonerBackground"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner-background/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_TonerLite"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toner-lite/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_Watercolor"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_Terrain"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_TerrainBackground"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/terrain-background/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Stamen_TopOSMRelief"){
+#        return("http://stamen-tiles-{s}.a.ssl.fastly.net/toposm-color-relief/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Esri_WorldStreetMap"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldTopoMap"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldImagery"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldTerrain"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Terrain_Base/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldShadedRelief"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Shaded_Relief/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldPhysical"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/World_Physical_Map/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_OceanBasemap"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/Ocean_Basemap/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_NatGeoWorldMap"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/NatGeo_World_Map/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Esri_WorldGrayCanvas"){
+#        return("http://server.arcgisonline.com/ArcGIS/rest/services/Canvas/World_Light_Gray_Base/MapServer/tile/{z}/{y}/{x}")
+#    }
+#    else if(name=="Acetate_all"){
+#        return("http://a{s}.acetate.geoiq.com/tiles/acetate-hillshading/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="Acetate_terrain"){
+#        return("http://a{s}.acetate.geoiq.com/tiles/terrain/{z}/{x}/{y}.png")
+#    }
+#    else if(name=="HERE_satelliteDay"){
+#        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/satellite.day/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
+#    }
+#    else if(name=="HERE_hybridDayMobile"){
+#        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/hybrid.day.mobile/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
+#    }
+#    else if(name=="HERE_hybridDay"){
+#        return("http://{s}.{base}.maps.cit.api.here.com/maptile/2.1/maptile/{mapID}/hybrid.day/{z}/{x}/{y}/256/png8?app_id={app_id}&app_code={app_code}")
+#    }
+#    else{
+#        stop("Map layer not currently supported. Note that you can ")
+#    }
+#
+#}
 
 
 
@@ -357,4 +357,4 @@ urlTemplate <- function(name="Stamen_Toner"){
 #     app_code: 'dq2MYIvjAotR8tHvY8Q_Dg',
 #     base: 'aerial',
 #     maxZoom: 20
-# });
\ No newline at end of file
+# });
